#!/usr/bin/env python

import pymongo
import os
import argparse
import logging
import multiprocessing as mp
from lib import utils

# Command line parsing
parser = argparse.ArgumentParser(
    description="Dump the tweets of a database to a JSON file")
parser.add_argument("-H", "--host", type=str, default="localhost")
parser.add_argument("-p", "--port", type=int, default=27017)
parser.add_argument("-s", "--pagesize", type=int, default=1000)
parser.add_argument("-v", "--verbose", action="store_true")
parser.add_argument("database", type=str)
args = parser.parse_args()

# Activate logging
logformat = "[%(asctime)s]: %(message)s"
dateformat = "%H:%M:%S"
if args.verbose:
    logging.basicConfig(
        level=logging.DEBUG, format=logformat, datefmt=dateformat)
else:
    logging.basicConfig(
        level=logging.ERROR, format=logformat, datefmt=dateformat)

# Initialize some variables
script_dir = os.path.dirname(__file__)
output_dir = os.path.join(script_dir, "pymongodump", args.database)
header_file = os.path.join(script_dir, "header.txt")
with open(header_file) as f:
    header = f.readline()
buffer_tweets = {}

# MongoDB connection to get page index
client = pymongo.MongoClient(args.host, args.port)
database_tweets = client[args.database]["tweets"]
page_index = utils.get_page_index(database_tweets, args.pagesize)
client.close()


# Build a picklable function that we can pass to map
def write_page(
        page, host=args.host, port=args.port, database=args.database,
        pagesize=args.pagesize, header=header, outputdir=output_dir):
    utils.write_tweets_to_files(
        host, port, database, pagesize, header, output_dir, page)


# Make the computation
with mp.Pool() as pool:
    pool.map(write_page, page_index)

utils.generate_metadata_file(output_dir)
